@@ -10,12 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from tuskarclient.common import base
-from tuskarclient.openstack.common.apiclient import base as common_base
+from tuskarclient.openstack.common.apiclient import base
 from tuskarclient.v2 import roles
 
 
-class Plan(common_base.Resource):
+class Plan(base.Resource):
     """Represents an instance of a Plan in the Tuskar API.
 
     :param manager: Manager object
@@ -28,7 +27,7 @@ class Plan(common_base.Resource):
         self.roles = [roles.Role(None, role) for role in self.roles]
 
 
-class Templates(common_base.Resource):
+class Templates(base.Resource):
     """Represents sets of templates of a Plan in the Tuskar API.
 
     :param manager: Manager object
@@ -37,7 +36,7 @@ class Templates(common_base.Resource):
     """
 
 
-class PlanManager(base.Manager):
+class PlanManager(base.BaseManager):
     """PlanManager interacts with the Tuskar API and provides CRUD
     operations for the Plan type.
     """
@@ -49,9 +48,9 @@ class PlanManager(base.Manager):
     def _path(plan_id=None):
 
         if plan_id:
-            return '/v2/plans/%s' % plan_id
+            return '/plans/%s' % plan_id
 
-        return '/v2/plans'
+        return '/plans'
 
     def _roles_path(self, plan_id, role_id=None):
         roles_path = '%s/roles' % self._path(plan_id)
@@ -76,7 +75,7 @@ class PlanManager(base.Manager):
         :return: A Plan instance or None if its not found.
         :rtype: tuskarclient.v2.plans.Plan or None
         """
-        return self._get(self._single_path(plan_uuid))
+        return self._get(self._path(plan_uuid))
 
     def list(self):
         """Get a list of the existing Plans
@@ -93,25 +92,25 @@ class PlanManager(base.Manager):
         :type fields: string
 
         :return: A Plan instance or None if its not found.
-        :rtype: tuskarclient.v1.plans.Plan
+        :rtype: tuskarclient.v2.plans.Plan
         """
-        return self._create(self._path(), fields)
+        return self._post(self._path(), fields)
 
-    def patch(self, plan_uuid, attribute_list):
+    def patch(self, plan_uuid, parameter_list):
         """Patch an existing Plan.
 
         :param plan_uuid: UUID of the Plan.
         :type plan_uuid: string
 
-        :param attribute_list: a list of attribute name/value dicts
+        :param parameter_list: a list of parameter name/value dicts
              Example: [{'name': <attr_name>, 'value': <attr_value>}]
-        :type attribute_list: list
+        :type parameter_list: list
 
         :return: A Plan instance or None if its not found.
         :rtype: tuskarclient.v2.plans.Plan or None
         """
-        return self._patch(self._single_path(plan_uuid),
-                           attribute_list)
+        return self._patch(self._path(plan_uuid),
+                           parameter_list)
 
     def delete(self, plan_uuid):
         """Delete a Plan.
@@ -122,7 +121,7 @@ class PlanManager(base.Manager):
         :return: None
         :rtype: None
         """
-        return self._delete(self._single_path(plan_uuid))
+        return self._delete(self._path(plan_uuid))
 
     def add_role(self, plan_uuid, role_uuid):
         """Adds a Role to a Plan.
@@ -136,7 +135,7 @@ class PlanManager(base.Manager):
         :return: A Plan instance or None if its not found.
         :rtype: tuskarclient.v2.plans.Plan
         """
-        return self._create(self._roles_path(plan_uuid), {'uuid': role_uuid})
+        return self._post(self._roles_path(plan_uuid), {'uuid': role_uuid})
 
     def remove_role(self, plan_uuid, role_uuid):
         """Removes a Role from a Plan.
@@ -150,10 +149,9 @@ class PlanManager(base.Manager):
         :return: A Plan instance or None if its not found.
         :rtype: tuskarclient.v2.plans.Plan
         """
-        resp, body = self.api.json_request(
-            'DELETE',
-            self._roles_path(plan_uuid, role_uuid)
-        )
+
+        rep, body = self._delete(self._roles_path(plan_uuid, role_uuid))
+
         return self.resource_class(self, body)
 
     def templates(self, plan_uuid):
@@ -166,5 +164,7 @@ class PlanManager(base.Manager):
         :rtype: dict
         """
 
-        return self._get(self._templates_path(plan_uuid),
-                         obj_class=Templates).to_dict()
+        self.resource_class = Templates
+        res = self._get(self._templates_path(plan_uuid)).to_dict()
+        self.resource_class = Plan
+        return res
